Class: Pinnacle::Client

Inherits:
PinnacleBaseClient show all
Defined in:
lib/pinnacle/pinnacle_client.rb

Overview

Client class that extends PinnacleBaseClient with custom methods for webhook processing and file uploads.

Instance Method Summary collapse

Methods inherited from PinnacleBaseClient

#audiences, #brands, #calls, #campaigns, #contacts, #conversations, #forms, #initialize, #network, #phone_numbers, #rcs, #status, #webhooks

Constructor Details

This class inherits a constructor from Pinnacle::PinnacleBaseClient

Instance Method Details

#messagesPinnacle::Wrapper::Messages::Client

Returns an enhanced messages client with webhook processing support.



14
15
16
# File 'lib/pinnacle/pinnacle_client.rb', line 14

def messages
  @messages ||= Pinnacle::Wrapper::Messages::Client.new(client: @raw_client)
end

#toolsPinnacle::Wrapper::Tools::Client

Returns an enhanced tools client with file upload helper.



21
22
23
# File 'lib/pinnacle/pinnacle_client.rb', line 21

def tools
  @tools ||= Pinnacle::Wrapper::Tools::Client.new(client: @raw_client)
end

#voicePinnacle::Wrapper::Voice::Client

Returns an enhanced voice client with WebSocket stream helpers.



28
29
30
# File 'lib/pinnacle/pinnacle_client.rb', line 28

def voice
  @voice ||= Pinnacle::Wrapper::Voice::Client.new(client: @raw_client)
end