Class: Pinnacle::Types::CampaignStatusEventCarrierLaunchesCarriers

Inherits:
Internal::Types::Model show all
Defined in:
lib/pinnacle/types/campaign_status_event_carrier_launches_carriers.rb

Overview

Per-carrier launch status. Each carrier moves through ‘NOT_LAUNCHED` → `PENDING` → `LAUNCHED` as Pinnacle submits the agent for review and the carrier accepts it. The agent is only deliverable on a carrier once that carrier reports `LAUNCHED`.

Method Summary

Methods inherited from Internal::Types::Model

#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h

Methods included from Internal::Types::Type

#coerce, #strict!, #strict?

Methods included from Internal::JSON::Serializable

#dump, #load

Constructor Details

This class inherits a constructor from Pinnacle::Internal::Types::Model