Class: Pinnacle::Types::CampaignStatusEventCarrierLaunchesVerification
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Pinnacle::Types::CampaignStatusEventCarrierLaunchesVerification
- Defined in:
- lib/pinnacle/types/campaign_status_event_carrier_launches_verification.rb
Overview
External verifier status. AEGIS (the U.S. carrier vetting authority used by AT&T, T-Mobile, and Verizon) and Google each send a verification email to the brand’s contact address. Each verifier moves through ‘NOT_SENT` → `SENT` → `VERIFIED` once the brand replies and the verifier confirms ownership.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Pinnacle::Internal::Types::Model