Class: Pinnacle::Types::FallbackMessage

Inherits:
Internal::Types::Model show all
Defined in:
lib/pinnacle/types/fallback_message.rb

Overview

SMS/MMS fallback message to send if the RCS message fails to deliver.

When a recipient’s device doesn’t support RCS, this fallback message will be sent as SMS or MMS instead. The fallback is sent from the specified phone number.

> Note: At least one of ‘text` or `mediaUrls` must be provided. Fallback messages require a verified `from` phone number with SMS/MMS sending capabilities.

> Billing: You will be charged the standard SMS or MMS rate for the fallback message. The original RCS message will not be charged if the fallback is sent instead.

Method Summary

Methods inherited from Internal::Types::Model

#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h

Methods included from Internal::Types::Type

#coerce, #strict!, #strict?

Methods included from Internal::JSON::Serializable

#dump, #load

Constructor Details

This class inherits a constructor from Pinnacle::Internal::Types::Model