Class: Pinnacle::Messages::Blast::Types::BlastRcsRequestOptionsStandaloneCard
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Pinnacle::Messages::Blast::Types::BlastRcsRequestOptionsStandaloneCard
- Defined in:
- lib/pinnacle/messages/blast/types/blast_rcs_request_options_standalone_card.rb
Overview
Configure standalone card layout options for enhanced visual presentation.
> **⚠️ Important Restriction** > > This option is **only valid for single card messages**. Using it with multiple cards will cause the request to fail with a validation error.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Pinnacle::Internal::Types::Model