Class: Pinnacle::Types::CampaignStatusEvent

Inherits:
Internal::Types::Model show all
Defined in:
lib/pinnacle/types/campaign_status_event.rb

Overview

Webhook body delivered to subscribers of ‘CAMPAIGN.STATUS` whenever an RCS campaign’s per-carrier launch status or verification status (AEGIS / Google) changes. ‘CAMPAIGN.STATUS` is only supported for RCS agent senders — the attach call rejects phone-number senders with `400 Bad Request`. Verify the `PINNACLE-SIGNING-SECRET` header matches the signing secret of the webhook this event was delivered to before trusting the payload.

Method Summary

Methods inherited from Internal::Types::Model

#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h

Methods included from Internal::Types::Type

#coerce, #strict!, #strict?

Methods included from Internal::JSON::Serializable

#dump, #load

Constructor Details

This class inherits a constructor from Pinnacle::Internal::Types::Model