Class: Pinnacle::Types::SubscriberMatchResponseMatches
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Pinnacle::Types::SubscriberMatchResponseMatches
- Defined in:
- lib/pinnacle/types/subscriber_match_response_matches.rb
Overview
Match strength for each evaluated subscriber attribute.
-
‘exact`: Carrier record matches the submitted value exactly.
-
‘high`: Strong match with minor formatting or normalization differences.
-
‘partial`: Some parts match, but the value is not a strong match.
-
‘low`: Weak match.
-
‘none`: Carrier record does not match the submitted value.
-
‘unavailable`: Carrier could not evaluate this attribute.
-
‘included-with-address-match`: Attribute was evaluated as part of the overall address match.
-
‘unknown`: Carrier returned a match value Pinnacle does not recognize yet.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Pinnacle::Internal::Types::Model